% Copyright (C) 2008 Medical College of Wisconsin.
% All rights reserved.
% 
% This software is distributed freely for academic and non-profit use. It
% should not be distributed or used for any commercial purpose without
% written permission from the Medical College of Wisconsin. For details
% please see User License Agreement.


% alpha-Ketogluterate Dehydrogenase (EC 1.2.4.2/EC 2.3.1.61/EC 1.8.1.4)
% reaction.

% 18mar15: Note: proton concentration may be wrong, generates negative
% numbers.

clear all;

%% Setting up and running Example 1
% (1.) Setting parameter values (no buffering)
B_X   = 0;      % Additional proton buffering capacity
K_BX = 1e-7;    % Dissociation constant of additional proton buffer
par(1) = .1;     % Vmf_AKGDH
par(2) = 25.0;     % Kir1
T = 25;             % Temperature

% (2.) Setting initial values
xo(1) = 5e-3;       % alpha-Ketogluterate (M)
xo(2) = 1e-3;       % COAS (M)
xo(3) = 1e-3;       % NAD (M)
xo(4) = 0;          % CO2tot (M)
xo(5) = 2e-3;       % SuccinylcoA (M)
xo(6) = 1e-3;          % NADH (M)
xo(7) = 1e-3;          % ATP (M)
xo(8) = 1e-4;          % ADP (M)
xo(9) = 1e-7;       % [H] (M)
xo(10) = 1e-3;      % [Mg] (M)
xo(11) = 150e-3;    % [K] (M)
tspan = 15/100;
% (3.) Running for 15-second time course
[t,x] = ode23t(@AKGDH,[0:tspan:15],xo,[],T,B_X,K_BX,par);
% (4.) Plotting results
figure(1); p = plot(t,x(:,1)*1e3,'k-',t,x(:,5)*1e3,'k:',t,x(:,5)*1e3,'k.');
set(p,'linewidth',1.5);
text(1,4.75,'Ketogluterate','Fontsize',14);
text(1,2.25,'SuccinylcoA','Fontsize',14);
text(1,0,'COAS','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(2); p = plot(t,x(:,3)*1e3,'k-',t,x(:,6)*1e3,'k:');
set(p,'linewidth',1.5);
text(2,1.5,'NAD','Fontsize',14);
text(2,.5,'NADH','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(3); p = plot(t,-log10(x(:,9)),'k-','LineWidth',1.5);
ylabel('pH','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);
figure(4); p = plot(t,x(:,7)*1e3,'k-',t,x(:,8)*1e3,'k:',t,x(:,4)*1e3,'ko');
set(p,'linewidth',1.5);
text(2,.95,'ATP','Fontsize',14);
text(2,.15,'ADP','Fontsize',14);
text(5,.8,'CO2','Fontsize',14);
ylabel('Concentration (mM)','Fontsize',14);
xlabel('Time (sec)','Fontsize',14);
set(gca,'Fontsize',14);

Table = array2table([t,x],'variableNames',{'Time','BISEN_Keto','BISEN_COAS','BISEN_NAD','BISEN_CO2','BISEN_SucCoA','NADH', 'ATP','ADP','BISEN_H','BISEN_Mg','BISEN_K'});
S1 = 'KetoBisenOutput';
S2 = '.csv';
filename1 = strcat(S1);  % Append runtime to filename
filename = strcat(filename1,S2);
%filename = 'KetoBisenOutput.csv';
writetable(Table,filename);
%%
